jsTree v.1.0 - hotkeys documentation

# jsTree v.1.0 - hotkeys plugin

## Description

The `hotkeys` plugin enables keyboard navigation and shortcuts. Depends on the jquery.hotkeys plugin

## Configuration

Expects an object:
each key is the keyboard shortcut (for possible values check the hotkeys plugin)
each values is a function executed in the instance's context, the return value is used as a return value for the event.

Simple example:

`"del" : function () { this.remove(); }`

## Demos

### Using the hotkeys plugin

Try pressing `up`/`down`/`left`/`right`/`space`/`f2`/`del`.

- Root node 1
  - Child node 1
  - Child node 2
- Root node 2

## API

### .enable_hotkeys ( )

Enable shortcuts on the instance (enabled by default).

### .disable_hotkeys ( )

Disable shortcuts on the instance.